@@ -1,13 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2022 -- leonerd@leonerd.org.uk
 
-use Object::Pad 0.43;
+use Object::Pad 0.57;
 
-package Tickit::ContainerWidget 0.54;
+package Tickit::ContainerWidget 0.56;
 class Tickit::ContainerWidget
-   extends Tickit::Widget;
+   :isa(Tickit::Widget);
 
 use Carp;
 
@@ -204,9 +204,10 @@ method window_lost
 
 method _on_win_focus
 {
+   my ( $win, $evtype, $childwin ) = @_;
    $self->SUPER::_on_win_focus( @_ );
 
-   $self->set_style_tag( "focus-child" => $_[1] ) if $_[2];
+   $self->set_style_tag( "focus-child" => $evtype ) if $childwin;
 }
 
 =head2 find_child
