@@ -1,13 +1,15 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2022 -- leonerd@leonerd.org.uk
 
-use Object::Pad 0.43;  # ADJUST
+use Object::Pad 0.57;
 
-package Tickit::Widget::RadioButton 0.33;
+package Tickit::Widget::RadioButton 0.35;
 class Tickit::Widget::RadioButton
-   extends Tickit::Widget;
+   :isa(Tickit::Widget);
+
+use Object::Pad qw( :experimental(init_expr) );
 
 use Tickit::Style;
 
@@ -153,12 +155,7 @@ is passed to the group's C<on_changed> callback.
 has $_label     :reader         :param;
 has $_on_toggle :reader :writer :param = undef;
 has $_value     :reader :writer :param = undef;
-has $_group     :reader         :param = undef;
-
-ADJUST
-{
-   $_group //= Tickit::Widget::RadioButton::Group->new;
-}
+has $_group     :reader         :param { Tickit::Widget::RadioButton::Group->new };
 
 method lines
 {
@@ -202,7 +199,7 @@ Returns or sets the label text of the button.
 
 method set_label
 {
-   $_label = $_[0];
+   ( $_label ) = @_;
    $self->reshape;
    $self->redraw;
 }
